@@ -6,7 +6,7 @@ import re
 import requests
 
 
-class KafkaConnect():
+class KafkaConnect:
     """A client for the Confluent Platform Kafka Connect REST API.
     Args:
         url (str): The base URL for the Kafka Connect REST API.
@@ -14,15 +14,20 @@ class KafkaConnect():
         ssl_verify (bool): Whether to verify the SSL certificate when making requests to the Kafka Connect REST API. Defaults to True.
         logger (logging.Logger): The logger to be used. If not specified, a new logger will be created.
     """
-    def __init__(self, url="http://localhost:8083", auth=None, ssl_verify=True, logger=None):
+
+    def __init__(
+        self, url="http://localhost:8083", auth=None, ssl_verify=True, logger=None
+    ):
         self.url = url
         self.headers = {"Content-Type": "application/json"}
 
         # Split the auth string into username and password and store them as a tuple
         if auth:
-            if ':' not in auth:
-                raise ValueError("Invalid auth string. Expected a colon-delimited string of `username` and `password`.")
-            username, password = auth.split(':')
+            if ":" not in auth:
+                raise ValueError(
+                    "Invalid auth string. Expected a colon-delimited string of `username` and `password`."
+                )
+            username, password = auth.split(":")
             self.auth = (username.strip(), password.strip())
         else:
             self.auth = None
@@ -30,6 +35,7 @@ class KafkaConnect():
         # If ssl_verify is False, disable SSL warnings
         if not ssl_verify:
             import urllib3
+
             urllib3.disable_warnings()
         self.verify = ssl_verify
 
@@ -46,71 +52,85 @@ class KafkaConnect():
         response.raise_for_status()
         return response.json()
 
-    def list_connectors(self, expand=None, connector_pattern=None):
+    def __filter_by_name(self, connectors, pattern):
+        """Filter connectors based on a regex pattern.
+        Args:
+            connectors (List[str] or Dict[str, Any]): The list or dictionary of connectors to filter.
+            pattern (str): The regex pattern to match the connector name. Defaults to `None`.
+        Returns:
+            List[str] or Dict[str, Any]: The filtered connectors.
+        """
+        if not pattern:
+            filtered_connectors = connectors
+
+        elif isinstance(connectors, list):
+            filtered_connectors = [
+                conn for conn in connectors if re.match(pattern, conn)
+            ]
+
+        elif isinstance(connectors, dict):
+            filtered_connectors = {
+                conn: data
+                for conn, data in connectors.items()
+                if re.match(pattern, conn)
+            }
+        return filtered_connectors
+    
+    def __filter_by_state(self, connectors, state):
+        """Filter connectors based on state.
+
+        Args:
+            connectors (List[str] or Dict[str, Any]): The list or dictionary of connectors to filter.
+            state (str): The state of a connector to filter.
+
+        Returns:
+            List[str] or Dict[str, Any]: The filtered connectors.
+        """
+        if not state:
+            return connectors
+    
+        if isinstance(connectors, list):
+            connectors_status = self.list_connectors(expand="status")
+            filtered_connectors = [
+                conn
+                for conn in connectors
+                if connectors_status.get(conn, {}).get("status", {}).get("connector", {}).get("state", "").lower() == state.lower()
+            ]
+        
+        if isinstance(connectors, dict):
+            try:
+                filtered_connectors = {
+                    conn: data
+                    for conn, data in connectors.items()
+                    if data["status"]["connector"]["state"].lower() == state.lower()
+                }
+            except Exception as e:
+                connectors_status = self.list_connectors(expand="status")
+                filtered_connectors = {
+                    conn: data
+                    for conn, data in connectors.items()
+                    if connectors_status.get(conn, {}).get("status", {}).get("connector", {}).get("state", "").lower() == state.lower()
+                }
+        
+        return filtered_connectors
+
+    def list_connectors(self, expand=None, pattern=None, state=None):
         """Get the list of connectors.
         Args:
             expand (str): Optional parameter that retrieves additional information about the connectors.
                 Valid values are "status" and "info".
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be listed.
+            pattern (str): Only list connectors that match the regex pattern.
+            state (str): Only list connectors that match the state.
         Returns:
             list or dict: The list of connector names or dictionary of connector names and its details.
         """
-        self.logger.info("Listing connectors")
+        self.logger.info(f"Listing connectors{' with expand=' + expand if expand else ''}")
         url = f"{self.url}/connectors"
         params = {"expand": expand}
         response = requests.get(url, auth=self.auth, verify=self.verify, params=params)
         response.raise_for_status()
         connectors = response.json()
-
-        if expand:
-            filtered_connectors = {}
-            for connector, data in connectors.items():
-                if connector_pattern:
-                    if not re.match(connector_pattern, connector):
-                        continue
-                filtered_connectors[connector] = data
-            return filtered_connectors
-        else:
-            filtered_connectors = []
-            for connector in connectors:
-                if connector_pattern:
-                    if not re.match(connector_pattern, connector):
-                        continue
-                filtered_connectors.append(connector)
-            return filtered_connectors
-    
-    def get_connector(self, connector):
-        """Get the details of a single connector.
-        Args:
-            connector (str): The name of the connector.
-        Returns:
-            Dict[str, Any]: The details of the connector.
-        """
-        self.logger.info(f"Getting connector: {connector}")
-        url = f"{self.url}/connectors/{connector}"
-        response = requests.get(url, auth=self.auth, verify=self.verify)
-        response.raise_for_status()
-        return response.json()
-
-    def get_all_connectors(self, connector_pattern=None):
-        """Get the details of all connectors.
-        Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be retrieved.
-        Returns:
-            Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
-        """
-        self.logger.info(f"Get the details of all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
-        responses = {}
-        for connector in self.list_connectors():
-            self.logger.debug(f"Filtering {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.get_connector(connector)
-
-        return responses
+        return self.__filter_by_state(self.__filter_by_name(connectors, pattern=pattern), state=state)
 
     def create_connector(self, config):
         """Create a new connector.
@@ -123,17 +143,19 @@ class KafkaConnect():
         """
         self.logger.info(f"Creating connector: {config.get('name')}")
         url = f"{self.url}/connectors"
-        response = requests.post(url, auth=self.auth, verify=self.verify, headers=self.headers, data=json.dumps(config))
-        
+        response = requests.post(
+            url,
+            auth=self.auth,
+            verify=self.verify,
+            headers=self.headers,
+            data=json.dumps(config),
+        )
+
+        response.raise_for_status()
         if response.status_code == 409:
             self.logger.error("Connector already exists or rebalance is in process.")
-        
-        response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
+        else:
+            return response.json()
 
     def update_connector(self, connector, config):
         """Update an existing connector.
@@ -143,25 +165,40 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-    
+
         if "config" in config:
-            self.logger.error('The payload is not wrapped in {"config": {}} as in the POST request. The config is directly provided.')
+            self.logger.error(
+                'The payload is not wrapped in {"config": {}} as in the POST request. The config is directly provided.'
+            )
 
-        self.logger.info(f"Updating connector: {connector}")
+        self.logger.info(f"Updating {connector} connector")
         url = f"{self.url}/connectors/{connector}/config"
-        response = requests.put(url, headers=self.headers, auth=self.auth, verify=self.verify, data=json.dumps(config))
+        response = requests.put(
+            url,
+            headers=self.headers,
+            auth=self.auth,
+            verify=self.verify,
+            data=json.dumps(config),
+        )
 
+        response.raise_for_status()
         if response.status_code == 409:
             self.logger.error("Connector rebalance is in process.")
         else:
             return response.json()
 
+    def get_connector(self, connector):
+        """Get the details of a single connector.
+        Args:
+            connector (str): The name of the connector.
+        Returns:
+            Dict[str, Any]: The details of the connector.
+        """
+        self.logger.info(f"Getting {connector} connector")
+        url = f"{self.url}/connectors/{connector}"
+        response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
+        return response.json()
 
     def get_connector_config(self, connector):
         """Get the configuration of a single connector.
@@ -175,26 +212,6 @@ class KafkaConnect():
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
-    
-    def get_all_connector_configs(self, connector_pattern=None):
-        """Get the config of all connectors.
-        Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connector configs will be retrieved.
-        Returns:
-            Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
-        """
-        self.logger.info(f"Get the config of all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
-        responses = {}
-        for connector in self.list_connectors():
-            self.logger.debug(f"Filtering {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.get_connector_config(connector)
-
-        return responses
 
     def get_connector_status(self, connector):
         """Get the status of a single connector.
@@ -208,55 +225,32 @@ class KafkaConnect():
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
         return response.json()
-    
-    def get_all_connector_statuses(self, connector_pattern=None):
-        """Get the status of all connectors.
-        Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connector statuses will be retrieved.
-        Returns:
-            Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
-        """
-        self.logger.info(f"Get the status of all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
-        responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = status
-
-        return responses
 
     def restart_connector(self, connector, include_tasks=False, only_failed=False):
         """Restart a single connector.
         Args:
             connector (str): The name of the connector.
             include_tasks (bool): If `True`, the tasks of the connector will also be restarted.
-                Defaults to `False`.
-            only_failed (bool): Whether to restart only failed Task objects. Defaults to `False`.
+                Defaults to `None`.
+            only_failed (bool): Whether to restart only failed Task objects. Defaults to `None`.
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-        self.logger.info(f"Restarting connector: {connector}")
+        self.logger.info(f"Restarting {connector} connector")
         url = f"{self.url}/connectors/{connector}/restart"
         params = {"includeTasks": include_tasks, "onlyFailed": only_failed}
         response = requests.post(url, auth=self.auth, verify=self.verify, params=params)
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        
+
         if response.status_code == 200:
             self.logger.info("Connector restarted successfully.")
-            return data
+            return response.json()
         elif response.status_code == 202:
             self.logger.info("Connector restart request accepted.")
-            return data
+            return response.json()
         elif response.status_code == 204:
-            self.logger.info("Connector restart request successful, but no response body returned.")
-            return data
+            self.logger.info(
+                "Connector restart request successful, but no response body returned."
+            )
         elif response.status_code == 404:
             self.logger.error("Connector not found.")
             raise HTTPError(response.text)
@@ -266,31 +260,29 @@ class KafkaConnect():
         elif response.status_code == 500:
             self.logger.error("Connector restart request timed out.")
             raise HTTPError(response.text)
-        
+
         response.raise_for_status()
-        return data
-    
-    def restart_all_connectors(self, include_tasks=False, only_failed=False, connector_pattern=None):
+        return None
+
+    def restart_all_connectors(
+        self, include_tasks=False, only_failed=False, pattern=None, state=None
+    ):
         """Restart all connectors.
         Args:
             include_tasks (bool): Whether to include tasks when restarting the connector. Default is False.
             only_failed (bool): Whether to only restart failed tasks. Default is False.
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be restarted.
+            pattern (str): The regex pattern to match the connector name. Defaults to `None`.
+            state (str): The connector state to match the connectors status. Defaults to `None`.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Restarting all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-
+        self.logger.info(
+            f"Restarting all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
+        )
         responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector} connector: {status}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.restart_connector(connector, include_tasks, only_failed)
-
-        return responses
+        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+            self.restart_connector(connector, include_tasks, only_failed)
+        return None
 
     def pause_connector(self, connector):
         """Pause a single connector.
@@ -299,38 +291,28 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-        self.logger.info(f"Pausing connector: {connector}")
+        self.logger.info(f"Pausing {connector} connector")
         url = f"{self.url}/connectors/{connector}/pause"
         response = requests.put(url, auth=self.auth, verify=self.verify)
+        if response.status_code == 202:
+            self.logger.info("Connector pause successful, but no response body returned.")
         response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
-    
-    def pause_all_connectors(self, connector_pattern=None):
+        return None
+
+    def pause_all_connectors(self, pattern=None, state=None):
         """Pause all connectors.
         Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all running connectors will be paused.
+            pattern (str): The regex pattern to match the connector name. Defaults to `None`.
+            state (str): The connector state to match the connectors status. Defaults to `None`.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Pausing all running connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-        
-        responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector} connector: {status}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            if status.get("status", {}).get("connector", {}).get("state", None).upper() == "RUNNING":
-                responses[connector] = self.pause_connector(connector)
-            else:
-                self.logger.debug(f"Skipping the {connector} connector because it is not in a RUNNING state.")
-
-        return responses
+        self.logger.info(
+            f"Pausing all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
+        )
+        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+            self.pause_connector(connector)
+        return None
 
     def resume_connector(self, connector):
         """Resume a single connector.
@@ -339,37 +321,28 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-        self.logger.info(f"Resuming connector: {connector}")
+        self.logger.info(f"Resuming {connector} connector")
         url = f"{self.url}/connectors/{connector}/resume"
         response = requests.put(url, auth=self.auth, verify=self.verify)
+        if response.status_code == 202:
+            self.logger.debug("Connector resumed successful, but no response body returned.")
         response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
+        return None
 
-    def resume_all_connectors(self, connector_pattern=None):
+    def resume_all_connectors(self, pattern=None, state=None):
         """Resume all connectors.
         Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all paused connectors will be resumed.
+            pattern (str): The regex pattern to match the connector name. Defaults to `None`.
+            state (str): The connector state to match the connectors status. Defaults to `None`.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Resuming all paused connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-        responses = {}
-        for connector, status in self.list_connectors(expand="status").items():
-            self.logger.debug(f"Filtering {connector} connector: {status}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            if status.get("status", {}).get("connector", {}).get("state", None).upper() == "PAUSED":
-                responses[connector] = self.resume_connector(connector)
-            else:
-                self.logger.debug(f"Skipping the {connector} connector because it is not in a PAUSED state.")
-
-        return responses
+        self.logger.info(
+            f"Resuming all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
+        )
+        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+            self.resume_connector(connector)
+        return None
 
     def delete_connector(self, connector):
         """Delete a single connector.
@@ -378,34 +351,28 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-        self.logger.info(f"Deleting connector: {connector}")
+        self.logger.info(f"Deleting {connector} connector")
         url = f"{self.url}/connectors/{connector}"
         response = requests.delete(url, auth=self.auth, verify=self.verify)
+        if response.status_code == 204:
+            self.logger.info("Connector resumed successful, but no content returned.")
         response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
-    
-    def delete_all_connectors(self, connector_pattern=None):
+        return None
+
+    def delete_all_connectors(self, pattern=None, state=None):
         """Delete all connectors.
         Args:
-            connector_pattern (str): The regex pattern to match the connector name. If not provided, all connectors will be deleted.
+            pattern (str): The regex pattern to match the connector name. Defaults to `None`.
+            state (str): The connector state to match the connectors status. Defaults to `None`.
         Returns:
             Dict[str, Dict[str, Any]]: A dictionary of responses, where the keys are the connector names and the values are the responses.
         """
-        self.logger.info(f"Deleting all connectors{' matching the pattern: ' + connector_pattern if connector_pattern else ''}")
-        responses = {}
-        for connector in self.list_connectors():
-            self.logger.debug(f"Filtering connector: {connector}")
-
-            if connector_pattern and not re.match(connector_pattern, connector):
-                continue
-
-            responses[connector] = self.delete_connector(connector)
-
-        return responses
+        self.logger.info(
+            f"Deleting all{' ' + state if state else ''} connectors{' matching the pattern: ' + pattern if pattern else ''}"
+        )
+        for connector, status in self.list_connectors(expand="status", pattern=pattern, state=state).items():
+            self.delete_connector(connector)
+        return None
 
     def list_connector_tasks(self, connector):
         """Get the list of tasks for a connector.
@@ -414,7 +381,7 @@ class KafkaConnect():
         Returns:
             List[int]: The list of task IDs for the connector.
         """
-        self.logger.info(f"Getting tasks for connector: {connector}")
+        self.logger.info(f"Getting tasks for {connector} connector")
         url = f"{self.url}/connectors/{connector}/tasks"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
@@ -428,7 +395,9 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API.
         """
-        self.logger.info(f"Getting task status for connector: {connector} and task_id: {task_id}")
+        self.logger.info(
+            f"Getting task status for {task_id} task for {connector} connector"
+        )
         url = f"{self.url}/connectors/{connector}/tasks/{task_id}/status"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
@@ -442,15 +411,13 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-        self.logger.info(f"Restarting task {task_id} of connector: {connector}")
+        self.logger.info(f"Restarting {task_id} task of {connector} connector")
         url = f"{self.url}/connectors/{connector}/tasks/{task_id}/restart"
         response = requests.post(url, auth=self.auth, verify=self.verify)
+        if response.status_code == 200:
+            self.logger.info("Connector topic names reset successful, but no response body returned.")
         response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
+        return None
 
     def list_connector_topics(self, connector):
         """Get the list of topics for a connector.
@@ -459,7 +426,7 @@ class KafkaConnect():
         Returns:
             List[str]: The list of topics for the connector.
         """
-        self.logger.info(f"Getting topics for connector: {connector}")
+        self.logger.info(f"Getting topics for {connector} connector")
         url = f"{self.url}/connectors/{connector}/topics"
         response = requests.get(url, auth=self.auth, verify=self.verify)
         response.raise_for_status()
@@ -472,15 +439,13 @@ class KafkaConnect():
         Returns:
             Dict[str, Any]: The response from the REST API, or an empty dictionary if the response is null or if there is a JSONDecodeError.
         """
-        self.logger.info(f"Resetting topics for connector: {connector}")
+        self.logger.info(f"Resetting topics for {connector} connector")
         url = f"{self.url}/connectors/{connector}/topics/reset"
         response = requests.put(url, auth=self.auth, verify=self.verify)
+        if response.status_code == 200:
+            self.logger.info("Connector topic names reset successful, but no response body returned.")
         response.raise_for_status()
-        try:
-            return response.json()
-        except JSONDecodeError:
-            data = None
-        return data
+        return None
 
     def list_connector_plugins(self):
         """Get the list of connector plugins.
@@ -504,10 +469,12 @@ class KafkaConnect():
         """
         self.logger.info(f"Validating config for plugin: {plugin}")
         url = f"{self.url}/connector-plugins/{plugin}/config/validate"
-        response = requests.put(url, auth=self.auth, verify=self.verify, headers=self.headers, data=json.dumps(config))
+        response = requests.put(
+            url,
+            auth=self.auth,
+            verify=self.verify,
+            headers=self.headers,
+            data=json.dumps(config),
+        )
         response.raise_for_status()
-        try:
-            data = response.json()
-        except JSONDecodeError:
-            data = None
-        return data
+        return response.json()
